head	1.2;
access;
symbols
	RELEASE_4_9_0:1.1
	RELEASE_5_1_0:1.1
	RELEASE_4_8_0:1.1
	RELEASE_5_0_0:1.1
	RELEASE_4_7_0:1.1;
locks; strict;
comment	@# @;


1.2
date	2003.10.27.19.48.03;	author tobez;	state dead;
branches;
next	1.1;

1.1
date	2002.08.20.20.58.32;	author tobez;	state Exp;
branches;
next	;


desc
@@


1.2
log
@Update to 5.8.1.

Also:

Make suidperl optional (ENABLE_SUIDPERL knob).  Switch to perlmalloc by
default, unless threaded perl is built, to improve performance.
Modernize pkg-plist (switch to SITE_PERL where possible).  Update WWW.

Many thanks to foxfair who prepared most of this update.
@
text
@$FreeBSD: ports/lang/perl5.8/files/patch-lib_pm,v 1.1 2002/08/20 20:58:32 tobez Exp $

--- lib/lib_pm.PL.orig	Wed Jun  5 03:05:46 2002
+++ lib/lib_pm.PL	Tue Aug 20 21:32:55 2002
@@@@ -71,30 +71,31 @@@@ sub import {
 
     my %names;
     foreach (reverse @@_) {
-	if ($_ eq '') {
+	my $path = $_;
+	if ($path eq '') {
 	    require Carp;
 	    Carp::carp("Empty compile time value given to use lib");
 	}
 
-	local $_ = _nativize($_);
+	$path = _nativize($path);
 
-	if (-e && ! -d _) {
+	if (-e $path && ! -d _) {
 	    require Carp;
 	    Carp::carp("Parameter to use lib must be directory, not file");
 	}
-	unshift(@@INC, $_);
+	unshift(@@INC, $path);
 	# Add any previous version directories we found at configure time
 	foreach my $incver (@@inc_version_list)
 	{
 	    my $dir = $Is_MacOS
-		? File::Spec->catdir( $_, $incver )
-		: "$_/$incver";
+		? File::Spec->catdir( $path, $incver )
+		: "$path/$incver";
 	    unshift(@@INC, $dir) if -d $dir;
 	}
 	# Put a corresponding archlib directory in front of $_ if it
 	# looks like $_ has an archlib directory below it.
 	my($arch_auto_dir, $arch_dir, $version_dir, $version_arch_dir)
-	    = _get_dirs($_);
+	    = _get_dirs($path);
 	unshift(@@INC, $arch_dir)         if -d $arch_auto_dir;
 	unshift(@@INC, $version_dir)      if -d $version_dir;
 	unshift(@@INC, $version_arch_dir) if -d $version_arch_dir;
@


1.1
log
@o Make perl -MConfig -e 'use lib $Config{installsitelib}' work
o Bump PORTREVISION

Prompted by:	green
@
text
@d1 1
a1 1
$FreeBSD$
@
@@@@ -71,30 +71,31 @@@@ sub import {
 	    unshift(@@INC, $dir) if -d $dir;
 	}
-	# Put a corresponding archlib directory in front of $_ if it
-	# looks like $_ has an archlib directory below it.
+	# Put a corresponding archlib directory in front of $path if it
+	# looks like $path has an archlib directory below it.
 	my($arch_auto_dir, $arch_dir, $version_dir, $version_arch_dir)

